@@ -12,19 +12,14 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from typing import TYPE_CHECKING, TypeVar, Union
-
-from selenium import webdriver
+from typing import TypeVar
 
 from appium.common.helper import extract_const_attributes
 from appium.common.logger import logger
+from appium.protocols.webdriver.can_execute_commands import CanExecuteCommands
 from appium.webdriver.mobilecommand import MobileCommand as Command
 
-if TYPE_CHECKING:
-    # noinspection PyUnresolvedReferences
-    from appium.webdriver.webdriver import WebDriver
-
-T = TypeVar('T', bound=Union['WebDriver', 'Gsm'])
+T = TypeVar('T', bound=CanExecuteCommands)
 
 
 class GsmCallActions:
@@ -52,7 +47,7 @@ class GsmVoiceState:
     ON = 'on'
 
 
-class Gsm(webdriver.Remote):
+class Gsm(CanExecuteCommands):
     def make_gsm_call(self: T, phone_number: str, action: str) -> T:
         """Make GSM call (Emulator only)
 
@@ -126,12 +121,12 @@ class Gsm(webdriver.Remote):
         self.execute(Command.SET_GSM_VOICE, {'state': state})
         return self
 
-    # pylint: disable=protected-access
-    # noinspection PyProtectedMember
-    def _addCommands(self) -> None:
-        self.command_executor._commands[Command.MAKE_GSM_CALL] = ('POST', '/session/$sessionId/appium/device/gsm_call')
-        self.command_executor._commands[Command.SET_GSM_SIGNAL] = (
+    def _add_commands(self) -> None:
+        # noinspection PyProtectedMember,PyUnresolvedReferences
+        commands = self.command_executor._commands
+        commands[Command.MAKE_GSM_CALL] = ('POST', '/session/$sessionId/appium/device/gsm_call')
+        commands[Command.SET_GSM_SIGNAL] = (
             'POST',
             '/session/$sessionId/appium/device/gsm_signal',
         )
-        self.command_executor._commands[Command.SET_GSM_VOICE] = ('POST', '/session/$sessionId/appium/device/gsm_voice')
+        commands[Command.SET_GSM_VOICE] = ('POST', '/session/$sessionId/appium/device/gsm_voice')
