@@ -12,15 +12,16 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from selenium import webdriver
+from typing import Optional
+
+from appium.protocols.webdriver.can_execute_commands import CanExecuteCommands
 
 from ..mobilecommand import MobileCommand as Command
 
 
-class DeviceTime(webdriver.Remote):
-
+class DeviceTime(CanExecuteCommands):
     @property
-    def device_time(self):
+    def device_time(self) -> str:
         """Returns the date and time from the device.
 
         Return:
@@ -28,18 +29,18 @@ class DeviceTime(webdriver.Remote):
         """
         return self.execute(Command.GET_DEVICE_TIME_GET, {})['value']
 
-    def get_device_time(self, format=None):
+    def get_device_time(self, format: Optional[str] = None) -> str:
         """Returns the date and time from the device.
 
         Args:
-            format (optional):  The set of format specifiers. Read https://momentjs.com/docs/
+            format:  The set of format specifiers. Read https://momentjs.com/docs/
                 to get the full list of supported datetime format specifiers.
                 If unset, return :func:`.device_time` as default format is `YYYY-MM-DDTHH:mm:ssZ`,
                 which complies to ISO-8601
 
         Usage:
-            self.driver.get_device_time()
-            self.driver.get_device_time("YYYY-MM-DD")
+            | self.driver.get_device_time()
+            | self.driver.get_device_time("YYYY-MM-DD")
 
         Return:
             str: The date and time
@@ -48,10 +49,14 @@ class DeviceTime(webdriver.Remote):
             return self.device_time
         return self.execute(Command.GET_DEVICE_TIME_POST, {'format': format})['value']
 
-    # pylint: disable=protected-access
-
-    def _addCommands(self):
-        self.command_executor._commands[Command.GET_DEVICE_TIME_GET] = \
-            ('GET', '/session/$sessionId/appium/device/system_time')
-        self.command_executor._commands[Command.GET_DEVICE_TIME_POST] = \
-            ('POST', '/session/$sessionId/appium/device/system_time')
+    def _add_commands(self) -> None:
+        # noinspection PyProtectedMember,PyUnresolvedReferences
+        commands = self.command_executor._commands
+        commands[Command.GET_DEVICE_TIME_GET] = (
+            'GET',
+            '/session/$sessionId/appium/device/system_time',
+        )
+        commands[Command.GET_DEVICE_TIME_POST] = (
+            'POST',
+            '/session/$sessionId/appium/device/system_time',
+        )
