@@ -12,23 +12,18 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from typing import TYPE_CHECKING, Dict, List, TypeVar, Union
+from typing import Dict, List, TypeVar, Union
 
-from selenium import webdriver
+from appium.protocols.webdriver.can_execute_commands import CanExecuteCommands
 
 from ..mobilecommand import MobileCommand as Command
 
-if TYPE_CHECKING:
-    # noinspection PyUnresolvedReferences
-    from appium.webdriver.webdriver import WebDriver
-
-T = TypeVar('T', bound=Union['WebDriver', 'LogEvent'])
+T = TypeVar('T', bound=CanExecuteCommands)
 
 
-class LogEvent(webdriver.Remote):
-
-    def get_events(self: T, type: List[str] = None) -> Dict[str, Union[str, int]]:
-        """ Retrieves events information from the current session
+class LogEvent(CanExecuteCommands):
+    def get_events(self, type: List[str] = None) -> Dict[str, Union[str, int]]:
+        """Retrieves events information from the current session
         (Since Appium 1.16.0)
 
         Args:
@@ -64,17 +59,12 @@ class LogEvent(webdriver.Remote):
         Returns:
             Union['WebDriver', 'LogEvent']: Self instance
         """
-        data = {
-            'vendor': vendor,
-            'event': event
-        }
+        data = {'vendor': vendor, 'event': event}
         self.execute(Command.LOG_EVENT, data)
         return self
 
-    # pylint: disable=protected-access
-    # noinspection PyProtectedMember
-    def _addCommands(self) -> None:
-        self.command_executor._commands[Command.GET_EVENTS] = \
-            ('POST', '/session/$sessionId/appium/events')
-        self.command_executor._commands[Command.LOG_EVENT] = \
-            ('POST', '/session/$sessionId/appium/log_event')
+    def _add_commands(self) -> None:
+        # noinspection PyProtectedMember,PyUnresolvedReferences
+        commands = self.command_executor._commands
+        commands[Command.GET_EVENTS] = ('POST', '/session/$sessionId/appium/events')
+        commands[Command.LOG_EVENT] = ('POST', '/session/$sessionId/appium/log_event')
