@@ -13,7 +13,7 @@
 # limitations under the License.
 
 import base64
-from typing import TYPE_CHECKING, Optional
+from typing import Optional, TypeVar
 
 from selenium.common.exceptions import InvalidArgumentException
 
@@ -21,8 +21,7 @@ from appium.protocols.webdriver.can_execute_commands import CanExecuteCommands
 
 from ..mobilecommand import MobileCommand as Command
 
-if TYPE_CHECKING:
-    from appium.webdriver.webdriver import WebDriver
+T = TypeVar('T', bound=CanExecuteCommands)
 
 
 class RemoteFS(CanExecuteCommands):
@@ -55,8 +54,8 @@ class RemoteFS(CanExecuteCommands):
         return self.execute(Command.PULL_FOLDER, data)['value']
 
     def push_file(
-        self, destination_path: str, base64data: Optional[str] = None, source_path: Optional[str] = None
-    ) -> 'WebDriver':
+        self: T, destination_path: str, base64data: Optional[str] = None, source_path: Optional[str] = None
+    ) -> T:
         """Puts the data from the file at `source_path`, encoded as Base64, in the file specified as `path`.
 
         Specify either `base64data` or `source_path`, if both specified default to `source_path`
@@ -87,7 +86,7 @@ class RemoteFS(CanExecuteCommands):
             'data': base64data,
         }
         self.execute(Command.PUSH_FILE, data)
-        return self  # type: ignore
+        return self
 
     def _add_commands(self) -> None:
         # noinspection PyProtectedMember,PyUnresolvedReferences
